Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(361)

Unified Diff: src/hydrogen.cc

Issue 6720017: Add inline non-transcendental cache version of log to lithium. (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler.h ('k') | src/ia32/lithium-codegen-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/hydrogen.cc
===================================================================
--- src/hydrogen.cc (revision 7492)
+++ src/hydrogen.cc (working copy)
@@ -3919,11 +3919,16 @@
return false;
}
// Don't inline deeper than two calls.
HEnvironment* env = environment();
- if (env->outer() != NULL && env->outer()->outer() != NULL) {
- TraceInline(target, "inline depth limit reached");
- return false;
+ int current_level = 1;
+ while (env->outer() != NULL) {
+ if (current_level == Compiler::kMaxInliningLevels) {
+ TraceInline(target, "inline depth limit reached");
+ return false;
+ }
+ current_level++;
+ env = env->outer();
}
// Don't inline recursive functions.
« no previous file with comments | « src/compiler.h ('k') | src/ia32/lithium-codegen-ia32.cc » ('j') | no next file with comments »
@@ -3919,11 +3919,16 @@
return false;
}
- // Don't inline deeper than two calls.
+ // Don't inline deeper than kMaxInliningLevels calls.
HEnvironment* env = environment();

Powered by Google App Engine
This is Rietveld 408576698